@@ -1,4 +1,4 @@
-/* $Id: gdict-pref.c,v 1.19 2002/05/17 17:33:47 kevinv Exp $ */
+/* $Id: gdict-pref.c,v 1.20 2003/05/31 06:03:27 dcransto Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -76,8 +76,6 @@ smart_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 
 void 
 gdict_pref_load (void) {
-    gchar *prefix, *server_key, *port_key;
-    gint i;
 
     gconf_client_add_dir(gdict_get_gconf_client (), "/apps/gnome-dictionary", GCONF_CLIENT_PRELOAD_NONE, NULL);
     
