@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.32 2002/06/12 15:47:42 gman Exp $ */
+/* $Id: main.c,v 1.34 2003/05/31 06:03:27 dcransto Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -51,25 +51,40 @@ static gint save_yourself_cb (GnomeClient       *client,
     return TRUE;
 }
 
-static gint client_die_cb (GnomeClient *client, gpointer client_data)
+/* static gint client_die_cb (GnomeClient *client, gpointer client_data)
 {
 	gtk_main_quit ();
+}*/
+
+const char **
+get_command_line_args (GnomeProgram *program)
+{
+	GValue value = { 0, };
+	poptContext ctx;
+
+	g_value_init (&value, G_TYPE_POINTER);
+	g_object_get_property (G_OBJECT (program), GNOME_PARAM_POPT_CONTEXT, &value);
+	ctx = g_value_get_pointer (&value);
+	g_value_unset (&value);
+
+	return poptGetArgs (ctx);
 }
 
 int main (int argc, char *argv[])
 {
     gint i;
-    GDictApplet * applet = NULL;
     GnomeClient *client;
+    GnomeProgram *program;
+    const char **args;
 
     bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
-    gnome_program_init ("gnome-dictionary",VERSION,
-                                      LIBGNOMEUI_MODULE,
-                                      argc, argv,
-                                      GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
+    program = gnome_program_init ("gnome-dictionary",VERSION,
+				  LIBGNOMEUI_MODULE,
+				  argc, argv,
+				  GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
 
 	
 
@@ -92,11 +107,12 @@ int main (int argc, char *argv[])
     gdict_init_context ();
     defbox->context = context;
 
-    for (i = 1;  i < argc;  i++)
-            if (argv[i][0] != '-') {
-                gdict_defbox_lookup(defbox, argv[i]);
-                break;
-            }
+    args = get_command_line_args (program);
+
+    for (i = 0; args != NULL && args[i] != NULL; i++) {
+	    gdict_defbox_lookup(defbox, (char *)args[i]);
+	    break;
+    }
 
     gtk_widget_show(gdict_app);
     gtk_main();
